@@ -206,7 +206,7 @@ class TrackerResource(ModelResource):
         authorization = Authorization() 
         serializer = PrettyJSONSerializer()
         always_return_data =  True
-        fields = ['points','digest','data','tracker_date','badges','course','completed','scoring']
+        fields = ['points','digest','data','tracker_date','badges','course','completed','scoring','metadata']
               
     def hydrate(self, bundle, request=None):
         # remove any id if this is submitted - otherwise it may overwrite existing tracker item
